From 7e57cced184f756c7c93b5a32ea0e2d4d6f9afe1 Mon Sep 17 00:00:00 2001
From: Richard Guo <guofenglinux@gmail.com>
Date: Wed, 6 Mar 2024 15:47:30 +0800
Subject: [PATCH v2 1/2] Make the order of the header file includes consistent
 in backend modules

---
 src/backend/access/brin/brin_bloom.c             | 8 ++++----
 src/backend/access/brin/brin_minmax_multi.c      | 6 +++---
 src/backend/access/common/printsimple.c          | 2 +-
 src/backend/access/hash/hash.c                   | 2 +-
 src/backend/access/heap/pruneheap.c              | 2 +-
 src/backend/access/spgist/spgtextproc.c          | 2 +-
 src/backend/access/transam/xlogarchive.c         | 2 +-
 src/backend/access/transam/xlogprefetcher.c      | 4 ++--
 src/backend/backup/basebackup_incremental.c      | 2 +-
 src/backend/catalog/pg_publication.c             | 2 +-
 src/backend/commands/statscmds.c                 | 2 +-
 src/backend/commands/vacuum.c                    | 2 +-
 src/backend/optimizer/util/relnode.c             | 2 +-
 src/backend/parser/parse_merge.c                 | 4 ++--
 src/backend/parser/parser.c                      | 2 +-
 src/backend/postmaster/walsummarizer.c           | 2 +-
 src/backend/replication/logical/tablesync.c      | 4 ++--
 src/backend/rewrite/rewriteSearchCycle.c         | 2 +-
 src/backend/statistics/extended_stats.c          | 2 +-
 src/backend/storage/ipc/procsignal.c             | 4 ++--
 src/backend/storage/sync/sync.c                  | 2 +-
 src/backend/utils/activity/pgstat_database.c     | 2 +-
 src/backend/utils/activity/pgstat_relation.c     | 2 +-
 src/backend/utils/activity/pgstat_wal.c          | 2 +-
 src/backend/utils/adt/array_userfuncs.c          | 4 ++--
 src/backend/utils/adt/jsonbsubs.c                | 2 +-
 src/backend/utils/adt/jsonpath.c                 | 2 +-
 src/backend/utils/adt/multirangetypes.c          | 4 ++--
 src/backend/utils/adt/multirangetypes_selfuncs.c | 2 +-
 src/backend/utils/adt/numutils.c                 | 2 +-
 src/backend/utils/adt/rangetypes_typanalyze.c    | 2 +-
 src/backend/utils/error/elog.c                   | 2 +-
 src/backend/utils/mb/stringinfo_mb.c             | 2 +-
 src/backend/utils/misc/guc_tables.c              | 2 +-
 src/backend/utils/misc/tzparser.c                | 2 +-
 src/backend/utils/mmgr/aset.c                    | 2 +-
 src/backend/utils/mmgr/generation.c              | 2 +-
 src/backend/utils/mmgr/slab.c                    | 2 +-
 src/backend/utils/sort/tuplesortvariants.c       | 2 +-
 39 files changed, 50 insertions(+), 50 deletions(-)

diff --git a/src/backend/access/brin/brin_bloom.c b/src/backend/access/brin/brin_bloom.c
index 32de039161..ebf3301627 100644
--- a/src/backend/access/brin/brin_bloom.c
+++ b/src/backend/access/brin/brin_bloom.c
@@ -114,22 +114,22 @@
  */
 #include "postgres.h"
 
-#include "access/genam.h"
+#include <math.h>
+
 #include "access/brin.h"
 #include "access/brin_internal.h"
 #include "access/brin_page.h"
 #include "access/brin_tuple.h"
+#include "access/genam.h"
 #include "access/htup_details.h"
 #include "access/reloptions.h"
 #include "catalog/pg_am.h"
-#include "catalog/pg_type.h"
 #include "catalog/pg_amop.h"
+#include "catalog/pg_type.h"
 #include "common/hashfn.h"
 #include "utils/fmgrprotos.h"
 #include "utils/rel.h"
 
-#include <math.h>
-
 #define BloomEqualStrategyNumber	1
 
 /*
diff --git a/src/backend/access/brin/brin_minmax_multi.c b/src/backend/access/brin/brin_minmax_multi.c
index 207a5a15b3..c5962c00d6 100644
--- a/src/backend/access/brin/brin_minmax_multi.c
+++ b/src/backend/access/brin/brin_minmax_multi.c
@@ -59,16 +59,16 @@
 /* needed for PGSQL_AF_INET */
 #include <sys/socket.h>
 
-#include "access/genam.h"
 #include "access/brin.h"
 #include "access/brin_internal.h"
 #include "access/brin_tuple.h"
+#include "access/genam.h"
+#include "access/htup_details.h"
 #include "access/reloptions.h"
 #include "access/stratnum.h"
-#include "access/htup_details.h"
-#include "catalog/pg_type.h"
 #include "catalog/pg_am.h"
 #include "catalog/pg_amop.h"
+#include "catalog/pg_type.h"
 #include "utils/array.h"
 #include "utils/builtins.h"
 #include "utils/date.h"
diff --git a/src/backend/access/common/printsimple.c b/src/backend/access/common/printsimple.c
index 8134c3be0c..4c5eedcdc1 100644
--- a/src/backend/access/common/printsimple.c
+++ b/src/backend/access/common/printsimple.c
@@ -20,8 +20,8 @@
 
 #include "access/printsimple.h"
 #include "catalog/pg_type.h"
-#include "libpq/protocol.h"
 #include "libpq/pqformat.h"
+#include "libpq/protocol.h"
 #include "utils/builtins.h"
 
 /*
diff --git a/src/backend/access/hash/hash.c b/src/backend/access/hash/hash.c
index 75bb02dfd7..01d06b7c32 100644
--- a/src/backend/access/hash/hash.c
+++ b/src/backend/access/hash/hash.c
@@ -27,8 +27,8 @@
 #include "commands/vacuum.h"
 #include "miscadmin.h"
 #include "nodes/execnodes.h"
-#include "pgstat.h"
 #include "optimizer/plancat.h"
+#include "pgstat.h"
 #include "utils/fmgrprotos.h"
 #include "utils/index_selfuncs.h"
 #include "utils/rel.h"
diff --git a/src/backend/access/heap/pruneheap.c b/src/backend/access/heap/pruneheap.c
index e2f2c37f4d..4f12413b8b 100644
--- a/src/backend/access/heap/pruneheap.c
+++ b/src/backend/access/heap/pruneheap.c
@@ -23,8 +23,8 @@
 #include "miscadmin.h"
 #include "pgstat.h"
 #include "storage/bufmgr.h"
-#include "utils/snapmgr.h"
 #include "utils/rel.h"
+#include "utils/snapmgr.h"
 
 /* Working data for heap_page_prune and subroutines */
 typedef struct
diff --git a/src/backend/access/spgist/spgtextproc.c b/src/backend/access/spgist/spgtextproc.c
index 06042feb11..3f08d330b6 100644
--- a/src/backend/access/spgist/spgtextproc.c
+++ b/src/backend/access/spgist/spgtextproc.c
@@ -40,8 +40,8 @@
 #include "postgres.h"
 
 #include "access/spgist.h"
-#include "common/int.h"
 #include "catalog/pg_type.h"
+#include "common/int.h"
 #include "mb/pg_wchar.h"
 #include "utils/datum.h"
 #include "utils/fmgrprotos.h"
diff --git a/src/backend/access/transam/xlogarchive.c b/src/backend/access/transam/xlogarchive.c
index 977a2fe06b..caa1f03d93 100644
--- a/src/backend/access/transam/xlogarchive.c
+++ b/src/backend/access/transam/xlogarchive.c
@@ -26,8 +26,8 @@
 #include "common/percentrepl.h"
 #include "miscadmin.h"
 #include "pgstat.h"
-#include "postmaster/startup.h"
 #include "postmaster/pgarch.h"
+#include "postmaster/startup.h"
 #include "replication/walsender.h"
 #include "storage/fd.h"
 #include "storage/ipc.h"
diff --git a/src/backend/access/transam/xlogprefetcher.c b/src/backend/access/transam/xlogprefetcher.c
index c3f52a8bd1..fc80c37e55 100644
--- a/src/backend/access/transam/xlogprefetcher.c
+++ b/src/backend/access/transam/xlogprefetcher.c
@@ -32,16 +32,16 @@
 #include "catalog/pg_control.h"
 #include "catalog/storage_xlog.h"
 #include "commands/dbcommands_xlog.h"
-#include "utils/fmgrprotos.h"
-#include "utils/timestamp.h"
 #include "funcapi.h"
 #include "miscadmin.h"
 #include "port/atomics.h"
 #include "storage/bufmgr.h"
 #include "storage/shmem.h"
 #include "storage/smgr.h"
+#include "utils/fmgrprotos.h"
 #include "utils/guc_hooks.h"
 #include "utils/hsearch.h"
+#include "utils/timestamp.h"
 
 /*
  * Every time we process this much WAL, we'll update the values in
diff --git a/src/backend/backup/basebackup_incremental.c b/src/backend/backup/basebackup_incremental.c
index ebc41f28be..2a522e4aea 100644
--- a/src/backend/backup/basebackup_incremental.c
+++ b/src/backend/backup/basebackup_incremental.c
@@ -23,9 +23,9 @@
 #include "backup/basebackup_incremental.h"
 #include "backup/walsummary.h"
 #include "common/blkreftable.h"
-#include "common/parse_manifest.h"
 #include "common/hashfn.h"
 #include "common/int.h"
+#include "common/parse_manifest.h"
 #include "datatype/timestamp.h"
 #include "postmaster/walsummarizer.h"
 #include "utils/timestamp.h"
diff --git a/src/backend/catalog/pg_publication.c b/src/backend/catalog/pg_publication.c
index ac05dc057f..0602398a54 100644
--- a/src/backend/catalog/pg_publication.c
+++ b/src/backend/catalog/pg_publication.c
@@ -22,8 +22,8 @@
 #include "catalog/dependency.h"
 #include "catalog/indexing.h"
 #include "catalog/namespace.h"
-#include "catalog/partition.h"
 #include "catalog/objectaddress.h"
+#include "catalog/partition.h"
 #include "catalog/pg_inherits.h"
 #include "catalog/pg_namespace.h"
 #include "catalog/pg_publication.h"
diff --git a/src/backend/commands/statscmds.c b/src/backend/commands/statscmds.c
index 6fa840fada..a855f750c7 100644
--- a/src/backend/commands/statscmds.c
+++ b/src/backend/commands/statscmds.c
@@ -32,8 +32,8 @@
 #include "statistics/statistics.h"
 #include "utils/acl.h"
 #include "utils/builtins.h"
-#include "utils/lsyscache.h"
 #include "utils/inval.h"
+#include "utils/lsyscache.h"
 #include "utils/rel.h"
 #include "utils/syscache.h"
 #include "utils/typcache.h"
diff --git a/src/backend/commands/vacuum.c b/src/backend/commands/vacuum.c
index 25281bbed9..223d33728d 100644
--- a/src/backend/commands/vacuum.c
+++ b/src/backend/commands/vacuum.c
@@ -34,8 +34,8 @@
 #include "access/tableam.h"
 #include "access/transam.h"
 #include "access/xact.h"
-#include "catalog/namespace.h"
 #include "catalog/index.h"
+#include "catalog/namespace.h"
 #include "catalog/pg_database.h"
 #include "catalog/pg_inherits.h"
 #include "commands/cluster.h"
diff --git a/src/backend/optimizer/util/relnode.c b/src/backend/optimizer/util/relnode.c
index e5f4062bfb..d791c4108d 100644
--- a/src/backend/optimizer/util/relnode.c
+++ b/src/backend/optimizer/util/relnode.c
@@ -29,8 +29,8 @@
 #include "optimizer/plancat.h"
 #include "optimizer/restrictinfo.h"
 #include "optimizer/tlist.h"
-#include "rewrite/rewriteManip.h"
 #include "parser/parse_relation.h"
+#include "rewrite/rewriteManip.h"
 #include "utils/hsearch.h"
 #include "utils/lsyscache.h"
 
diff --git a/src/backend/parser/parse_merge.c b/src/backend/parser/parse_merge.c
index 6b99f55688..a7d8ba7e98 100644
--- a/src/backend/parser/parse_merge.c
+++ b/src/backend/parser/parse_merge.c
@@ -18,14 +18,14 @@
 #include "access/sysattr.h"
 #include "nodes/makefuncs.h"
 #include "parser/analyze.h"
-#include "parser/parse_collate.h"
-#include "parser/parsetree.h"
 #include "parser/parse_clause.h"
+#include "parser/parse_collate.h"
 #include "parser/parse_cte.h"
 #include "parser/parse_expr.h"
 #include "parser/parse_merge.h"
 #include "parser/parse_relation.h"
 #include "parser/parse_target.h"
+#include "parser/parsetree.h"
 #include "utils/rel.h"
 
 static void setNamespaceForMergeWhen(ParseState *pstate,
diff --git a/src/backend/parser/parser.c b/src/backend/parser/parser.c
index 3a1fa91c1b..118488c3f3 100644
--- a/src/backend/parser/parser.c
+++ b/src/backend/parser/parser.c
@@ -21,8 +21,8 @@
 
 #include "postgres.h"
 
-#include "mb/pg_wchar.h"
 #include "gramparse.h"
+#include "mb/pg_wchar.h"
 #include "parser/parser.h"
 #include "parser/scansup.h"
 
diff --git a/src/backend/postmaster/walsummarizer.c b/src/backend/postmaster/walsummarizer.c
index 8bf8a03471..ec2874c18c 100644
--- a/src/backend/postmaster/walsummarizer.c
+++ b/src/backend/postmaster/walsummarizer.c
@@ -38,8 +38,8 @@
 #include "replication/walreceiver.h"
 #include "storage/fd.h"
 #include "storage/ipc.h"
-#include "storage/lwlock.h"
 #include "storage/latch.h"
+#include "storage/lwlock.h"
 #include "storage/proc.h"
 #include "storage/procsignal.h"
 #include "storage/shmem.h"
diff --git a/src/backend/replication/logical/tablesync.c b/src/backend/replication/logical/tablesync.c
index ee06629088..1061d5b61b 100644
--- a/src/backend/replication/logical/tablesync.c
+++ b/src/backend/replication/logical/tablesync.c
@@ -107,10 +107,10 @@
 #include "replication/logicallauncher.h"
 #include "replication/logicalrelation.h"
 #include "replication/logicalworker.h"
+#include "replication/origin.h"
+#include "replication/slot.h"
 #include "replication/walreceiver.h"
 #include "replication/worker_internal.h"
-#include "replication/slot.h"
-#include "replication/origin.h"
 #include "storage/ipc.h"
 #include "storage/lmgr.h"
 #include "utils/acl.h"
diff --git a/src/backend/rewrite/rewriteSearchCycle.c b/src/backend/rewrite/rewriteSearchCycle.c
index 911a901808..1c58003f9d 100644
--- a/src/backend/rewrite/rewriteSearchCycle.c
+++ b/src/backend/rewrite/rewriteSearchCycle.c
@@ -16,8 +16,8 @@
 #include "catalog/pg_operator_d.h"
 #include "catalog/pg_type_d.h"
 #include "nodes/makefuncs.h"
-#include "nodes/pg_list.h"
 #include "nodes/parsenodes.h"
+#include "nodes/pg_list.h"
 #include "nodes/primnodes.h"
 #include "parser/analyze.h"
 #include "parser/parsetree.h"
diff --git a/src/backend/statistics/extended_stats.c b/src/backend/statistics/extended_stats.c
index 5d7bdc9d12..f21bdc2ab9 100644
--- a/src/backend/statistics/extended_stats.c
+++ b/src/backend/statistics/extended_stats.c
@@ -23,9 +23,9 @@
 #include "catalog/indexing.h"
 #include "catalog/pg_statistic_ext.h"
 #include "catalog/pg_statistic_ext_data.h"
-#include "executor/executor.h"
 #include "commands/defrem.h"
 #include "commands/progress.h"
+#include "executor/executor.h"
 #include "miscadmin.h"
 #include "nodes/nodeFuncs.h"
 #include "optimizer/optimizer.h"
diff --git a/src/backend/storage/ipc/procsignal.c b/src/backend/storage/ipc/procsignal.c
index ca41b56952..4ed9cedcdd 100644
--- a/src/backend/storage/ipc/procsignal.c
+++ b/src/backend/storage/ipc/procsignal.c
@@ -18,18 +18,18 @@
 #include <unistd.h>
 
 #include "access/parallel.h"
-#include "port/pg_bitutils.h"
 #include "commands/async.h"
 #include "miscadmin.h"
 #include "pgstat.h"
+#include "port/pg_bitutils.h"
 #include "replication/logicalworker.h"
 #include "replication/walsender.h"
 #include "storage/condition_variable.h"
 #include "storage/ipc.h"
 #include "storage/latch.h"
 #include "storage/shmem.h"
-#include "storage/smgr.h"
 #include "storage/sinval.h"
+#include "storage/smgr.h"
 #include "tcop/tcopprot.h"
 #include "utils/memutils.h"
 
diff --git a/src/backend/storage/sync/sync.c b/src/backend/storage/sync/sync.c
index 4764e26f70..ab7137d0ff 100644
--- a/src/backend/storage/sync/sync.c
+++ b/src/backend/storage/sync/sync.c
@@ -18,8 +18,8 @@
 #include <fcntl.h>
 #include <sys/file.h>
 
-#include "access/commit_ts.h"
 #include "access/clog.h"
+#include "access/commit_ts.h"
 #include "access/multixact.h"
 #include "access/xlog.h"
 #include "miscadmin.h"
diff --git a/src/backend/utils/activity/pgstat_database.c b/src/backend/utils/activity/pgstat_database.c
index 1203c4cbd1..29bc090974 100644
--- a/src/backend/utils/activity/pgstat_database.c
+++ b/src/backend/utils/activity/pgstat_database.c
@@ -17,9 +17,9 @@
 
 #include "postgres.h"
 
+#include "storage/procsignal.h"
 #include "utils/pgstat_internal.h"
 #include "utils/timestamp.h"
-#include "storage/procsignal.h"
 
 
 static bool pgstat_should_report_connstat(void);
diff --git a/src/backend/utils/activity/pgstat_relation.c b/src/backend/utils/activity/pgstat_relation.c
index 40241e26d6..8a3f7d434c 100644
--- a/src/backend/utils/activity/pgstat_relation.c
+++ b/src/backend/utils/activity/pgstat_relation.c
@@ -19,12 +19,12 @@
 
 #include "access/twophase_rmgr.h"
 #include "access/xact.h"
+#include "catalog/catalog.h"
 #include "postmaster/autovacuum.h"
 #include "utils/memutils.h"
 #include "utils/pgstat_internal.h"
 #include "utils/rel.h"
 #include "utils/timestamp.h"
-#include "catalog/catalog.h"
 
 
 /* Record that's written to 2PC state file when pgstat state is persisted */
diff --git a/src/backend/utils/activity/pgstat_wal.c b/src/backend/utils/activity/pgstat_wal.c
index 1a3c0e1a66..0e374f133a 100644
--- a/src/backend/utils/activity/pgstat_wal.c
+++ b/src/backend/utils/activity/pgstat_wal.c
@@ -17,8 +17,8 @@
 
 #include "postgres.h"
 
-#include "utils/pgstat_internal.h"
 #include "executor/instrument.h"
+#include "utils/pgstat_internal.h"
 
 
 PgStat_PendingWalStats PendingWalStats = {0};
diff --git a/src/backend/utils/adt/array_userfuncs.c b/src/backend/utils/adt/array_userfuncs.c
index a643f2169a..6599be2ec5 100644
--- a/src/backend/utils/adt/array_userfuncs.c
+++ b/src/backend/utils/adt/array_userfuncs.c
@@ -13,13 +13,13 @@
 #include "postgres.h"
 
 #include "catalog/pg_type.h"
-#include "libpq/pqformat.h"
 #include "common/int.h"
 #include "common/pg_prng.h"
+#include "libpq/pqformat.h"
 #include "port/pg_bitutils.h"
 #include "utils/array.h"
-#include "utils/datum.h"
 #include "utils/builtins.h"
+#include "utils/datum.h"
 #include "utils/lsyscache.h"
 #include "utils/typcache.h"
 
diff --git a/src/backend/utils/adt/jsonbsubs.c b/src/backend/utils/adt/jsonbsubs.c
index d3edb010ed..2b037131c9 100644
--- a/src/backend/utils/adt/jsonbsubs.c
+++ b/src/backend/utils/adt/jsonbsubs.c
@@ -19,8 +19,8 @@
 #include "nodes/subscripting.h"
 #include "parser/parse_coerce.h"
 #include "parser/parse_expr.h"
-#include "utils/jsonb.h"
 #include "utils/builtins.h"
+#include "utils/jsonb.h"
 
 
 /* SubscriptingRefState.workspace for jsonb subscripting execution */
diff --git a/src/backend/utils/adt/jsonpath.c b/src/backend/utils/adt/jsonpath.c
index f4a5d00767..786a2b65c6 100644
--- a/src/backend/utils/adt/jsonpath.c
+++ b/src/backend/utils/adt/jsonpath.c
@@ -65,8 +65,8 @@
 
 #include "lib/stringinfo.h"
 #include "libpq/pqformat.h"
-#include "nodes/miscnodes.h"
 #include "miscadmin.h"
+#include "nodes/miscnodes.h"
 #include "utils/fmgrprotos.h"
 #include "utils/json.h"
 #include "utils/jsonpath.h"
diff --git a/src/backend/utils/adt/multirangetypes.c b/src/backend/utils/adt/multirangetypes.c
index a6c959a4e1..8f12c953ca 100644
--- a/src/backend/utils/adt/multirangetypes.c
+++ b/src/backend/utils/adt/multirangetypes.c
@@ -39,11 +39,11 @@
 #include "libpq/pqformat.h"
 #include "nodes/nodes.h"
 #include "port/pg_bitutils.h"
+#include "utils/array.h"
 #include "utils/builtins.h"
 #include "utils/lsyscache.h"
-#include "utils/rangetypes.h"
 #include "utils/multirangetypes.h"
-#include "utils/array.h"
+#include "utils/rangetypes.h"
 
 /* fn_extra cache entry for one of the range I/O functions */
 typedef struct MultirangeIOData
diff --git a/src/backend/utils/adt/multirangetypes_selfuncs.c b/src/backend/utils/adt/multirangetypes_selfuncs.c
index f97ff575f0..9e8558b599 100644
--- a/src/backend/utils/adt/multirangetypes_selfuncs.c
+++ b/src/backend/utils/adt/multirangetypes_selfuncs.c
@@ -25,8 +25,8 @@
 #include "utils/float.h"
 #include "utils/fmgrprotos.h"
 #include "utils/lsyscache.h"
-#include "utils/rangetypes.h"
 #include "utils/multirangetypes.h"
+#include "utils/rangetypes.h"
 #include "utils/selfuncs.h"
 #include "utils/typcache.h"
 
diff --git a/src/backend/utils/adt/numutils.c b/src/backend/utils/adt/numutils.c
index c08eea452c..adc1e8a4cb 100644
--- a/src/backend/utils/adt/numutils.c
+++ b/src/backend/utils/adt/numutils.c
@@ -18,8 +18,8 @@
 #include <limits.h>
 #include <ctype.h>
 
-#include "utils/builtins.h"
 #include "port/pg_bitutils.h"
+#include "utils/builtins.h"
 
 /*
  * A table of all two-digit numbers. This is used to speed up decimal digit
diff --git a/src/backend/utils/adt/rangetypes_typanalyze.c b/src/backend/utils/adt/rangetypes_typanalyze.c
index 47fc21b90f..3773f98115 100644
--- a/src/backend/utils/adt/rangetypes_typanalyze.c
+++ b/src/backend/utils/adt/rangetypes_typanalyze.c
@@ -29,8 +29,8 @@
 #include "utils/float.h"
 #include "utils/fmgrprotos.h"
 #include "utils/lsyscache.h"
-#include "utils/rangetypes.h"
 #include "utils/multirangetypes.h"
+#include "utils/rangetypes.h"
 #include "varatt.h"
 
 static int	float8_qsort_cmp(const void *a1, const void *a2, void *arg);
diff --git a/src/backend/utils/error/elog.c b/src/backend/utils/error/elog.c
index ed8aa5c9fa..52bc01058c 100644
--- a/src/backend/utils/error/elog.c
+++ b/src/backend/utils/error/elog.c
@@ -70,8 +70,8 @@
 #include "libpq/libpq.h"
 #include "libpq/pqformat.h"
 #include "mb/pg_wchar.h"
-#include "nodes/miscnodes.h"
 #include "miscadmin.h"
+#include "nodes/miscnodes.h"
 #include "pgstat.h"
 #include "postmaster/bgworker.h"
 #include "postmaster/postmaster.h"
diff --git a/src/backend/utils/mb/stringinfo_mb.c b/src/backend/utils/mb/stringinfo_mb.c
index f4af3909e8..241a6c2562 100644
--- a/src/backend/utils/mb/stringinfo_mb.c
+++ b/src/backend/utils/mb/stringinfo_mb.c
@@ -19,8 +19,8 @@
  */
 #include "postgres.h"
 
-#include "mb/stringinfo_mb.h"
 #include "mb/pg_wchar.h"
+#include "mb/stringinfo_mb.h"
 
 
 /*
diff --git a/src/backend/utils/misc/guc_tables.c b/src/backend/utils/misc/guc_tables.c
index d77214795d..57d9de4dd9 100644
--- a/src/backend/utils/misc/guc_tables.c
+++ b/src/backend/utils/misc/guc_tables.c
@@ -82,11 +82,11 @@
 #include "utils/float.h"
 #include "utils/guc_hooks.h"
 #include "utils/guc_tables.h"
+#include "utils/inval.h"
 #include "utils/memutils.h"
 #include "utils/pg_locale.h"
 #include "utils/plancache.h"
 #include "utils/ps_status.h"
-#include "utils/inval.h"
 #include "utils/xml.h"
 
 /* This value is normally passed in from the Makefile */
diff --git a/src/backend/utils/misc/tzparser.c b/src/backend/utils/misc/tzparser.c
index ad892ee3c3..21fd866d6d 100644
--- a/src/backend/utils/misc/tzparser.c
+++ b/src/backend/utils/misc/tzparser.c
@@ -26,10 +26,10 @@
 
 #include "miscadmin.h"
 #include "storage/fd.h"
+#include "utils/datetime.h"
 #include "utils/guc.h"
 #include "utils/memutils.h"
 #include "utils/tzparser.h"
-#include "utils/datetime.h"
 
 
 #define WHITESPACE " \t\n\r"
diff --git a/src/backend/utils/mmgr/aset.c b/src/backend/utils/mmgr/aset.c
index d2dcf526d6..751cc3408c 100644
--- a/src/backend/utils/mmgr/aset.c
+++ b/src/backend/utils/mmgr/aset.c
@@ -49,8 +49,8 @@
 #include "port/pg_bitutils.h"
 #include "utils/memdebug.h"
 #include "utils/memutils.h"
-#include "utils/memutils_memorychunk.h"
 #include "utils/memutils_internal.h"
+#include "utils/memutils_memorychunk.h"
 
 /*--------------------
  * Chunk freelist k holds chunks of size 1 << (k + ALLOC_MINBITS),
diff --git a/src/backend/utils/mmgr/generation.c b/src/backend/utils/mmgr/generation.c
index 9124d9b952..5d81af1f94 100644
--- a/src/backend/utils/mmgr/generation.c
+++ b/src/backend/utils/mmgr/generation.c
@@ -39,8 +39,8 @@
 #include "port/pg_bitutils.h"
 #include "utils/memdebug.h"
 #include "utils/memutils.h"
-#include "utils/memutils_memorychunk.h"
 #include "utils/memutils_internal.h"
+#include "utils/memutils_memorychunk.h"
 
 
 #define Generation_BLOCKHDRSZ	MAXALIGN(sizeof(GenerationBlock))
diff --git a/src/backend/utils/mmgr/slab.c b/src/backend/utils/mmgr/slab.c
index 516e1c95aa..3e15d59683 100644
--- a/src/backend/utils/mmgr/slab.c
+++ b/src/backend/utils/mmgr/slab.c
@@ -71,8 +71,8 @@
 #include "lib/ilist.h"
 #include "utils/memdebug.h"
 #include "utils/memutils.h"
-#include "utils/memutils_memorychunk.h"
 #include "utils/memutils_internal.h"
+#include "utils/memutils_memorychunk.h"
 
 #define Slab_BLOCKHDRSZ	MAXALIGN(sizeof(SlabBlock))
 
diff --git a/src/backend/utils/sort/tuplesortvariants.c b/src/backend/utils/sort/tuplesortvariants.c
index 08f9f16262..11de12d745 100644
--- a/src/backend/utils/sort/tuplesortvariants.c
+++ b/src/backend/utils/sort/tuplesortvariants.c
@@ -27,8 +27,8 @@
 #include "executor/executor.h"
 #include "pg_trace.h"
 #include "utils/datum.h"
-#include "utils/lsyscache.h"
 #include "utils/guc.h"
+#include "utils/lsyscache.h"
 #include "utils/tuplesort.h"
 
 
-- 
2.31.0

